@@ -1,6 +1,7 @@
 /*
     GNOME Commander - A GNOME based file manager
     Copyright (C) 2001-2006 Marcus Bjurman
+    Copyright (C) 2007-2010 Piotr Eljasiak
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -20,20 +21,12 @@
 #ifndef __LIB_GCMD_UTILS_H__
 #define __LIB_GCMD_UTILS_H__
 
-G_BEGIN_DECLS
+gchar *get_utf8 (const gchar *unknown);
 
-gchar *
-get_utf8 (const gchar *unknown);
+gchar *get_bold_text (const gchar *in);
 
-gchar *
-get_bold_text (const gchar *in);
+gchar *get_mono_text (const gchar *in);
 
-gchar *
-get_mono_text (const gchar *in);
-
-gchar *
-get_bold_mono_text (const gchar *in);
-
-G_END_DECLS
+gchar *get_bold_mono_text (const gchar *in);
 
 #endif //__LIB_GCMD_UTILS_H__
