@@ -1,7 +1,7 @@
 /*
     GNOME Commander - A GNOME based file manager
     Copyright (C) 2001-2006 Marcus Bjurman
-    Copyright (C) 2007-2009 Piotr Eljasiak
+    Copyright (C) 2007-2010 Piotr Eljasiak
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -35,8 +35,6 @@ typedef struct _CvsPluginPrivate CvsPluginPrivate;
 #include <libgcmd/libgcmd.h>
 #include "parser.h"
 
-G_BEGIN_DECLS
-
 struct _CvsPlugin
 {
     GnomeCmdPlugin parent;
@@ -62,6 +60,4 @@ GtkType cvs_plugin_get_type ();
 
 GnomeCmdPlugin *cvs_plugin_new ();
 
-G_END_DECLS
-
 #endif //__CVS_PLUGIN_H__
