@@ -1,6 +1,7 @@
 /*
     GNOME Commander - A GNOME based file manager
     Copyright (C) 2001-2006 Marcus Bjurman
+    Copyright (C) 2007-2010 Piotr Eljasiak
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -30,25 +31,23 @@
     GTK_CHECK_TYPE (obj, gnome_cmd_con_device_get_type ())
 
 
-typedef struct _GnomeCmdConDevice GnomeCmdConDevice;
-typedef struct _GnomeCmdConDeviceClass GnomeCmdConDeviceClass;
-typedef struct _GnomeCmdConDevicePrivate GnomeCmdConDevicePrivate;
+struct GnomeCmdConDevicePrivate;
 
 
-struct _GnomeCmdConDevice
+struct GnomeCmdConDevice
 {
     GnomeCmdCon parent;
 
     GnomeCmdConDevicePrivate *priv;
 };
 
-struct _GnomeCmdConDeviceClass
+struct GnomeCmdConDeviceClass
 {
     GnomeCmdConClass parent_class;
 };
 
 
-GtkType gnome_cmd_con_device_get_type (void);
+GtkType gnome_cmd_con_device_get_type ();
 
 GnomeCmdConDevice *gnome_cmd_con_device_new (const gchar *alias, const gchar *device_fn, const gchar *mountp, const gchar *icon_path);
 
