@@ -1,6 +1,7 @@
 /*
     GNOME Commander - A GNOME based file manager
     Copyright (C) 2001-2006 Marcus Bjurman
+    Copyright (C) 2007-2010 Piotr Eljasiak
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -126,6 +127,15 @@ inline _GnomeCmdConnectDialogPrivate::_GnomeCmdConnectDialogPrivate()
     user_entry = gtk_entry_new ();
     password_entry = gtk_entry_new ();
 
+    gtk_entry_set_activates_default (GTK_ENTRY (alias_entry), TRUE);
+    gtk_entry_set_activates_default (GTK_ENTRY (uri_entry), TRUE);
+    gtk_entry_set_activates_default (GTK_ENTRY (server_entry), TRUE);
+    gtk_entry_set_activates_default (GTK_ENTRY (share_entry), TRUE);
+    gtk_entry_set_activates_default (GTK_ENTRY (port_entry), TRUE);
+    gtk_entry_set_activates_default (GTK_ENTRY (folder_entry), TRUE);
+    gtk_entry_set_activates_default (GTK_ENTRY (user_entry), TRUE);
+    gtk_entry_set_activates_default (GTK_ENTRY (password_entry), TRUE);
+
     gtk_entry_set_visibility (GTK_ENTRY (password_entry), FALSE);
 
     // We need an extra ref so we can remove them from the table
@@ -435,7 +445,7 @@ static void port_insert_text (GtkEditable *editable, const gchar *new_text, gint
     if (new_text_length != 1 || !g_ascii_isdigit (new_text[0]))
     {
         gdk_display_beep (gtk_widget_get_display (GTK_WIDGET (editable)));
-        g_signal_stop_emission_by_name (editable, "insert_text");
+        g_signal_stop_emission_by_name (editable, "insert-text");
     }
 }
 
@@ -519,7 +529,7 @@ static void gnome_cmd_connect_dialog_init (GnomeCmdConnectDialog *dialog)
     gtk_widget_show (table);
     gtk_container_add (GTK_CONTAINER (align), table);
 
-    g_signal_connect (dialog->priv->port_entry, "insert_text", G_CALLBACK (port_insert_text), NULL);
+    g_signal_connect (dialog->priv->port_entry, "insert-text", G_CALLBACK (port_insert_text), NULL);
 
     setup_for_type (dialog);
 
@@ -550,7 +560,7 @@ GnomeCmdConFtp *gnome_cmd_connect_dialog_new (gboolean has_alias)
 
     gtk_combo_box_set_active (GTK_COMBO_BOX (conndlg->priv->type_combo), CON_SSH);
 
-    conndlg->priv->use_auth = gnome_cmd_data_get_use_gnome_auth_manager ();
+    conndlg->priv->use_auth = gnome_cmd_data.use_gnome_auth_manager;
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (conndlg->priv->auth_check), conndlg->priv->use_auth);
 
     gint response = gtk_dialog_run (GTK_DIALOG (dialog));
@@ -614,14 +624,47 @@ gboolean gnome_cmd_connect_dialog_edit (GnomeCmdConFtp *server)
             gtk_entry_set_text (GTK_ENTRY (conndlg->priv->uri_entry), con->uri);
 
             gtk_entry_set_text (GTK_ENTRY (conndlg->priv->server_entry), gnome_vfs_uri_get_host_name (uri));
-            // gtk_entry_set_text (GTK_ENTRY (conndlg->priv->share_entry), ???);
-            gtk_entry_set_text (GTK_ENTRY (conndlg->priv->folder_entry), gnome_vfs_uri_get_path (uri));
-            // gtk_entry_set_text (GTK_ENTRY (conndlg->priv->domain_entry), ???);
-            gtk_entry_set_text (GTK_ENTRY (conndlg->priv->user_entry), gnome_vfs_uri_get_user_name (uri));
-            gtk_entry_set_text (GTK_ENTRY (conndlg->priv->password_entry), gnome_vfs_uri_get_password (uri));
 
+            const gchar *path = gnome_vfs_uri_get_path (uri);
+            const gchar *user_name = gnome_vfs_uri_get_user_name (uri);
+            const gchar *password = gnome_vfs_uri_get_password (uri);
             guint port = gnome_vfs_uri_get_host_port (uri);
 
+            if (con->method==CON_SMB)
+            {
+                gchar **a = g_strsplit (path, "/", 3);
+
+                if (g_strv_length (a) > 2)
+                {
+                    gtk_entry_set_text (GTK_ENTRY (conndlg->priv->share_entry), a[1]);
+                    gtk_entry_set_text (GTK_ENTRY (conndlg->priv->folder_entry), a[2]);
+                }
+                else
+                    gtk_entry_set_text (GTK_ENTRY (conndlg->priv->folder_entry), path);
+
+                g_strfreev(a);
+
+                a = g_strsplit (user_name, ";", 2);
+
+                if (g_strv_length (a) > 1)
+                {
+                    gtk_entry_set_text (GTK_ENTRY (conndlg->priv->domain_entry), a[0]);
+                    gtk_entry_set_text (GTK_ENTRY (conndlg->priv->user_entry), a[1]);
+                }
+                else
+                    gtk_entry_set_text (GTK_ENTRY (conndlg->priv->user_entry), user_name);
+
+                g_strfreev(a);
+            }
+            else
+            {
+                gtk_entry_set_text (GTK_ENTRY (conndlg->priv->folder_entry), path);
+                gtk_entry_set_text (GTK_ENTRY (conndlg->priv->user_entry), user_name);
+            }
+
+            if (password)
+                gtk_entry_set_text (GTK_ENTRY (conndlg->priv->password_entry), password);
+
             if (port)
                 gtk_entry_set_text (GTK_ENTRY (conndlg->priv->port_entry), stringify(port).c_str());
 
