@@ -1,6 +1,7 @@
 /*
     GNOME Commander - A GNOME based file manager
     Copyright (C) 2001-2006 Marcus Bjurman
+    Copyright (C) 2007-2010 Piotr Eljasiak
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -18,6 +19,7 @@
 */
 
 #include <config.h>
+
 #include "gnome-cmd-includes.h"
 #include "gnome-cmd-data.h"
 #include "gnome-cmd-con-home.h"
@@ -27,11 +29,6 @@
 using namespace std;
 
 
-struct _GnomeCmdConHomePrivate
-{
-};
-
-
 static GnomeCmdConClass *parent_class = NULL;
 
 
@@ -83,8 +80,6 @@ static void destroy (GtkObject *object)
 {
     GnomeCmdConHome *con = GNOME_CMD_CON_HOME (object);
 
-    g_free (con->priv);
-
     if (GTK_OBJECT_CLASS (parent_class)->destroy)
         (*GTK_OBJECT_CLASS (parent_class)->destroy) (object);
 }
@@ -110,12 +105,10 @@ static void class_init (GnomeCmdConHomeClass *klass)
 
 static void init (GnomeCmdConHome *home_con)
 {
-    guint dev_icon_size = gnome_cmd_data_get_dev_icon_size ();
+    guint dev_icon_size = gnome_cmd_data.dev_icon_size;
 
     GnomeCmdCon *con = GNOME_CMD_CON (home_con);
 
-    home_con->priv = g_new0 (GnomeCmdConHomePrivate, 1);
-
     con->state = CON_STATE_OPEN;
     con->alias = g_strdup (_("Home"));
     con->method = CON_LOCAL;
@@ -144,7 +137,7 @@ static void init (GnomeCmdConHome *home_con)
  * Public functions
  ***********************************/
 
-GtkType gnome_cmd_con_home_get_type (void)
+GtkType gnome_cmd_con_home_get_type ()
 {
     static GtkType type = 0;
 
@@ -168,7 +161,7 @@ GtkType gnome_cmd_con_home_get_type (void)
 }
 
 
-GnomeCmdCon *gnome_cmd_con_home_new (void)
+GnomeCmdCon *gnome_cmd_con_home_new ()
 {
     GnomeCmdConHome *con = (GnomeCmdConHome *) gtk_type_new (gnome_cmd_con_home_get_type ());
 
