@@ -1,6 +1,7 @@
 /*
     GNOME Commander - A GNOME based file manager
     Copyright (C) 2001-2006 Marcus Bjurman
+    Copyright (C) 2007-2010 Piotr Eljasiak
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -30,26 +31,20 @@
     GTK_CHECK_TYPE (obj, gnome_cmd_con_home_get_type ())
 
 
-typedef struct _GnomeCmdConHome GnomeCmdConHome;
-typedef struct _GnomeCmdConHomeClass GnomeCmdConHomeClass;
-typedef struct _GnomeCmdConHomePrivate GnomeCmdConHomePrivate;
-
-
-struct _GnomeCmdConHome
+struct GnomeCmdConHome
 {
     GnomeCmdCon parent;
-
-    GnomeCmdConHomePrivate *priv;
 };
 
-struct _GnomeCmdConHomeClass
+
+struct GnomeCmdConHomeClass
 {
     GnomeCmdConClass parent_class;
 };
 
 
-GtkType gnome_cmd_con_home_get_type (void);
+GtkType gnome_cmd_con_home_get_type ();
 
-GnomeCmdCon *gnome_cmd_con_home_new (void);
+GnomeCmdCon *gnome_cmd_con_home_new ();
 
 #endif // __GNOME_CMD_CON_HOME_H__
