@@ -1,6 +1,7 @@
 /*
     GNOME Commander - A GNOME based file manager
     Copyright (C) 2001-2006 Marcus Bjurman
+    Copyright (C) 2007-2010 Piotr Eljasiak
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -29,28 +30,19 @@
     GTK_CHECK_TYPE (obj, gnome_cmd_con_smb_get_type ())
 
 
-typedef struct _GnomeCmdConSmb GnomeCmdConSmb;
-typedef struct _GnomeCmdConSmbClass GnomeCmdConSmbClass;
-typedef struct _GnomeCmdConSmbPrivate GnomeCmdConSmbPrivate;
-
-
-struct _GnomeCmdConSmb
+struct GnomeCmdConSmb
 {
     GnomeCmdCon parent;
-
-    GnomeCmdConSmbPrivate *priv;
 };
 
-struct _GnomeCmdConSmbClass
+struct GnomeCmdConSmbClass
 {
     GnomeCmdConClass parent_class;
 };
 
 
-GtkType
-gnome_cmd_con_smb_get_type (void);
+GtkType gnome_cmd_con_smb_get_type ();
 
-GnomeCmdCon *
-gnome_cmd_con_smb_new (void);
+GnomeCmdCon *gnome_cmd_con_smb_new ();
 
 #endif // __GNOME_CMD_CON_SMB_H__
