@@ -1,6 +1,7 @@
 /*
     GNOME Commander - A GNOME based file manager
     Copyright (C) 2001-2006 Marcus Bjurman
+    Copyright (C) 2007-2010 Piotr Eljasiak
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -18,6 +19,7 @@
 */
 
 #include <config.h>
+
 #include "gnome-cmd-includes.h"
 #include "gnome-cmd-data.h"
 #include "gnome-cmd-dir.h"
@@ -146,7 +148,7 @@ inline void create_delete_progress_win (DeleteData *data)
     bbox = create_hbuttonbox (data->progwin);
     gtk_container_add (GTK_CONTAINER (vbox), bbox);
 
-    button = create_stock_button_with_data (data->progwin, GNOME_STOCK_BUTTON_CANCEL, GTK_SIGNAL_FUNC (on_cancel), data);
+    button = create_stock_button_with_data (data->progwin, GTK_STOCK_CANCEL, GTK_SIGNAL_FUNC (on_cancel), data);
     GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
     gtk_container_add (GTK_CONTAINER (bbox), button);
 
@@ -158,36 +160,31 @@ inline void create_delete_progress_win (DeleteData *data)
 static void perform_delete_operation (DeleteData *data)
 {
     GList *uri_list = NULL;
-    gint num_files = g_list_length (data->files);
 
-    // Go through all files and add the uri of the appropriate ones to a list
-    for (gint i=0; i<num_files; i++)
+    // go through all files and add the uri of the appropriate ones to a list
+    for (GList *i=data->files; i; i=i->next)
     {
-        GnomeCmdFile *finfo = (GnomeCmdFile *) g_list_nth_data (data->files, i);
+        GnomeCmdFile *f = (GnomeCmdFile *) i->data;
 
-        if (strcmp(finfo->info->name, "..") == 0 || strcmp(finfo->info->name, ".") == 0)
+        if (f->is_dotdot || strcmp(f->info->name, ".") == 0)
             continue;
 
-        GnomeVFSURI *uri = gnome_cmd_file_get_uri (finfo);
+        GnomeVFSURI *uri = gnome_cmd_file_get_uri (f);
         if (!uri) continue;
 
-        gnome_vfs_uri_ref (uri);
-        uri_list = g_list_append (uri_list, uri);
+        uri_list = g_list_append (uri_list, gnome_vfs_uri_ref (uri));
     }
 
     if (uri_list)
     {
-        GnomeVFSXferOptions xferOptions = GNOME_VFS_XFER_DEFAULT;
-        GnomeVFSXferErrorMode xferErrorMode = GNOME_VFS_XFER_ERROR_MODE_QUERY;
+        gnome_vfs_xfer_delete_list (uri_list,
+                                    GNOME_VFS_XFER_ERROR_MODE_QUERY,
+                                    GNOME_VFS_XFER_DEFAULT,
+                                    (GnomeVFSXferProgressCallback) delete_progress_callback,
+                                    data);
 
-        GnomeVFSResult result = gnome_vfs_xfer_delete_list (uri_list,
-                                                            xferErrorMode,
-                                                            xferOptions,
-                                                            (GnomeVFSXferProgressCallback) delete_progress_callback,
-                                                            data);
-
-        // g_list_foreach (uri_list, (GFunc) gnome_vfs_uri_unref, NULL);
-        // g_list_free (uri_list);
+        g_list_foreach (uri_list, (GFunc) gnome_vfs_uri_unref, NULL);
+        g_list_free (uri_list);
     }
 
     data->delete_done = TRUE;
@@ -225,11 +222,11 @@ static gboolean update_delete_status_widgets (DeleteData *data)
         if (data->files)
             for (GList *tmp = data->files; tmp; tmp = tmp->next)
             {
-                GnomeCmdFile *finfo = GNOME_CMD_FILE (tmp->data);
-                GnomeVFSURI *uri = gnome_cmd_file_get_uri (finfo);
+                GnomeCmdFile *f = GNOME_CMD_FILE (tmp->data);
+                GnomeVFSURI *uri = gnome_cmd_file_get_uri (f);
 
                 if (!gnome_vfs_uri_exists (uri))
-                    gnome_cmd_file_is_deleted (finfo);
+                    gnome_cmd_file_is_deleted (f);
             }
 
         gtk_widget_destroy (data->progwin);
@@ -252,7 +249,7 @@ inline void do_delete (DeleteData *data)
     create_delete_progress_win (data);
 
     data->thread = g_thread_create ((GThreadFunc) perform_delete_operation, data, FALSE, NULL);
-    g_timeout_add (gnome_cmd_data_get_gui_update_rate (), (GSourceFunc) update_delete_status_widgets, data);
+    g_timeout_add (gnome_cmd_data.gui_update_rate, (GSourceFunc) update_delete_status_widgets, data);
 }
 
 
@@ -262,7 +259,7 @@ void gnome_cmd_delete_dialog_show (GList *files)
 
     gint response = 1;
 
-    if (gnome_cmd_data_get_confirm_delete ())
+    if (gnome_cmd_data.confirm_delete)
     {
         gchar *msg = NULL;
 
@@ -270,12 +267,12 @@ void gnome_cmd_delete_dialog_show (GList *files)
 
         if (n_files == 1)
         {
-            GnomeCmdFile *finfo = (GnomeCmdFile *) g_list_nth_data (files, 0);
+            GnomeCmdFile *f = (GnomeCmdFile *) g_list_nth_data (files, 0);
 
-            if (strcmp (finfo->info->name, "..") == 0)
+            if (f->is_dotdot)
                 return;
 
-            gchar *fname = get_utf8 (finfo->info->name);
+            gchar *fname = get_utf8 (f->info->name);
             msg = g_strdup_printf (_("Do you want to delete \"%s\"?"), fname);
             g_free (fname);
         }
