@@ -1,7 +1,7 @@
 /*
     GNOME Commander - A GNOME based file manager
     Copyright (C) 2001-2006 Marcus Bjurman
-    Copyright (C) 2007-2009 Piotr Eljasiak
+    Copyright (C) 2007-2010 Piotr Eljasiak
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -214,6 +214,8 @@ void gnome_cmd_file_setup (GnomeCmdFile *f, GnomeVFSFileInfo *info, GnomeCmdDir
     f->info = info;
     GNOME_CMD_FILE_INFO (f)->info = info;
 
+    f->is_dotdot = info->type==GNOME_VFS_FILE_TYPE_DIRECTORY && strcmp(info->name, "..")==0;    // check if file is '..'
+
     gchar *utf8_name;
 
     if (!gnome_cmd_data.case_sens_sort)
@@ -564,39 +566,39 @@ const gchar *gnome_cmd_file_get_size (GnomeCmdFile *file)
 }
 
 
-GnomeVFSFileSize gnome_cmd_file_get_tree_size (GnomeCmdFile *file)
+GnomeVFSFileSize gnome_cmd_file_get_tree_size (GnomeCmdFile *f)
 {
-    g_return_val_if_fail (file != NULL, 0);
+    g_return_val_if_fail (f != NULL, 0);
 
-    if (file->info->type != GNOME_VFS_FILE_TYPE_DIRECTORY)
-        return file->info->size;
+    if (f->info->type != GNOME_VFS_FILE_TYPE_DIRECTORY)
+        return f->info->size;
 
-    if (strcmp (file->info->name, "..") == 0)
+    if (f->is_dotdot)
         return 0;
 
-    if (file->priv->tree_size != -1)
-        return file->priv->tree_size;
+    if (f->priv->tree_size != -1)
+        return f->priv->tree_size;
 
-    GnomeVFSURI *uri = gnome_cmd_file_get_uri (file);
-    file->priv->tree_size = calc_tree_size (uri);
+    GnomeVFSURI *uri = gnome_cmd_file_get_uri (f);
+    f->priv->tree_size = calc_tree_size (uri);
     gnome_vfs_uri_unref (uri);
 
-    return file->priv->tree_size;
+    return f->priv->tree_size;
 }
 
 
-const gchar *gnome_cmd_file_get_tree_size_as_str (GnomeCmdFile *file)
+const gchar *gnome_cmd_file_get_tree_size_as_str (GnomeCmdFile *f)
 {
-    g_return_val_if_fail (file != NULL, NULL);
-    g_return_val_if_fail (file->info != NULL, NULL);
+    g_return_val_if_fail (f != NULL, NULL);
+    g_return_val_if_fail (f->info != NULL, NULL);
 
-    if (file->info->type != GNOME_VFS_FILE_TYPE_DIRECTORY)
-        return gnome_cmd_file_get_size (file);
+    if (f->info->type != GNOME_VFS_FILE_TYPE_DIRECTORY)
+        return gnome_cmd_file_get_size (f);
 
-    if (strcmp (file->info->name, "..") == 0)
-        return gnome_cmd_file_get_size (file);
+    if (f->is_dotdot)
+        return gnome_cmd_file_get_size (f);
 
-    return size2string (gnome_cmd_file_get_tree_size (file), gnome_cmd_data.size_disp_mode);
+    return size2string (gnome_cmd_file_get_tree_size (f), gnome_cmd_data.size_disp_mode);
 }
 
 
