@@ -1,7 +1,7 @@
 /*
     GNOME Commander - A GNOME based file manager
     Copyright (C) 2001-2006 Marcus Bjurman
-    Copyright (C) 2007-2009 Piotr Eljasiak
+    Copyright (C) 2007-2010 Piotr Eljasiak
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -968,7 +968,8 @@ gboolean gnome_cmd_main_win_keypressed (GnomeCmdMainWin *mw, GdkEventKey *event)
                 {
                     GnomeCmdFileSelector *fs = gnome_cmd_main_win_get_fs (mw, LEFT);
                     gnome_cmd_main_win_switch_fs (mw, fs);
-                    gnome_cmd_combo_popup_list (GNOME_CMD_COMBO (fs->con_combo));
+                    if (gnome_cmd_data.concombo_visibility)
+                        gnome_cmd_combo_popup_list (GNOME_CMD_COMBO (fs->con_combo));
                 }
                 return TRUE;
 
@@ -976,7 +977,8 @@ gboolean gnome_cmd_main_win_keypressed (GnomeCmdMainWin *mw, GdkEventKey *event)
                 {
                     GnomeCmdFileSelector *fs = gnome_cmd_main_win_get_fs (mw, RIGHT);
                     gnome_cmd_main_win_switch_fs (mw, fs);
-                    gnome_cmd_combo_popup_list (GNOME_CMD_COMBO (fs->con_combo));
+                    if (gnome_cmd_data.concombo_visibility)
+                        gnome_cmd_combo_popup_list (GNOME_CMD_COMBO (fs->con_combo));
                 }
                 return TRUE;
 
@@ -1013,17 +1015,30 @@ gboolean gnome_cmd_main_win_keypressed (GnomeCmdMainWin *mw, GdkEventKey *event)
             case GDK_u:
             case GDK_U:
                 {
-                    GnomeCmdDir *dir1 = gnome_cmd_main_win_get_fs (mw, LEFT)->get_directory();
-                    GnomeCmdDir *dir2 = gnome_cmd_main_win_get_fs (mw, RIGHT)->get_directory();
+                    GnomeCmdFileSelector *fs1 = gnome_cmd_main_win_get_fs (mw, LEFT);
+                    GnomeCmdFileSelector *fs2 = gnome_cmd_main_win_get_fs (mw, RIGHT);
 
-                    gnome_cmd_dir_ref (dir1);
-                    gnome_cmd_dir_ref (dir2);
+                    // swap widgets
+                    g_object_ref (fs1);
+                    g_object_ref (fs2);
+                    gtk_container_remove (GTK_CONTAINER (mw->priv->paned), *fs1);
+                    gtk_container_remove (GTK_CONTAINER (mw->priv->paned), *fs2);
+                    gtk_paned_pack1 (GTK_PANED (mw->priv->paned), *fs2, TRUE, TRUE);
+                    gtk_paned_pack2 (GTK_PANED (mw->priv->paned), *fs1, TRUE, TRUE);
+                    g_object_unref (fs1);
+                    g_object_unref (fs2);
 
-                    gnome_cmd_main_win_get_fs (mw, LEFT)->set_directory(dir2);
-                    gnome_cmd_main_win_get_fs (mw, RIGHT)->set_directory(dir1);
+                    // update priv->file_selector[]
+                    GtkWidget *swap = mw->priv->file_selector[LEFT];
+                    mw->priv->file_selector[LEFT] = mw->priv->file_selector[RIGHT];
+                    mw->priv->file_selector[RIGHT] = swap;
 
-                    gnome_cmd_dir_unref (dir1);
-                    gnome_cmd_dir_unref (dir2);
+                    // refocus ACTIVE fs
+                    gnome_cmd_main_win_focus_file_lists (mw);
+
+                    // update cmdline only for different directories
+                    if (fs1->get_directory()!=fs2->get_directory())
+                        gnome_cmd_main_win_switch_fs (mw, gnome_cmd_main_win_get_fs (mw, ACTIVE));
 
                     clear_event_key (event);
                 }
