@@ -1,6 +1,7 @@
 /*
     GNOME Commander - A GNOME based file manager
     Copyright (C) 2001-2006 Marcus Bjurman
+    Copyright (C) 2007-2010 Piotr Eljasiak
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -20,6 +21,6 @@
 #ifndef __GNOME_CMD_SMB_AUTH_H__
 #define __GNOME_CMD_SMB_AUTH_H__
 
-void gnome_cmd_smb_auth_init (void);
+void gnome_cmd_smb_auth_init ();
 
 #endif // __GNOME_CMD_SMB_AUTH_H__
