@@ -1,6 +1,7 @@
 /*
   GNOME Commander - A GNOME based file manager
   Copyright (C) 2001-2006 Marcus Bjurman
+  Copyright (C) 2007-2010 Piotr Eljasiak
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -112,7 +113,7 @@ const gchar *perm2numstring (GnomeVFSFilePermissions p, gchar *buf, guint max);
 const gchar *size2string (GnomeVFSFileSize size, GnomeCmdSizeDispMode size_disp_mode);
 const gchar *time2string (time_t t, const gchar *date_format);
 
-void mime_exec_single (GnomeCmdFile *finfo);
+void mime_exec_single (GnomeCmdFile *f);
 void mime_exec_multiple (GList *files, GnomeCmdApp *app);
 
 void clear_event_key (GdkEventKey *event);
@@ -184,14 +185,14 @@ inline void set_cursor_default_for_widget (GtkWidget *widget)
         gdk_window_set_cursor (widget->window, NULL);
 }
 
-void set_cursor_busy (void);
-void set_cursor_default (void);
+void set_cursor_busy ();
+void set_cursor_default ();
 
-GList *app_get_linked_libs (GnomeCmdFile *finfo);
-gboolean app_needs_terminal (GnomeCmdFile *finfo);
+GList *app_get_linked_libs (GnomeCmdFile *f);
+gboolean app_needs_terminal (GnomeCmdFile *f);
 
 gchar *get_temp_download_filepath (const gchar *fname);
-void remove_temp_download_dir (void);
+void remove_temp_download_dir ();
 
 GtkWidget *create_ui_pixmap (GtkWidget *window,
                              GnomeUIPixmapType pixmap_type,
@@ -229,6 +230,7 @@ GList *patlist_new (const gchar *pattern_string);
 void patlist_free (GList *pattern_list);
 gboolean patlist_matches (GList *pattern_list, const gchar *s);
 
+void gnome_cmd_toggle_file_name_selection (GtkWidget *entry);
 
 inline void gnome_cmd_show_message (GtkWindow *parent, std::string message, const gchar *secondary_text=NULL)
 {
@@ -269,7 +271,7 @@ inline void gnome_cmd_error_message (const gchar *title, GError *error)
 
 // Insert an item with an inline xpm icon and a user data pointer
 #define GNOMEUIINFO_ITEM_FILENAME(label, tooltip, callback, filename) \
-    { GNOME_APP_UI_ITEM, label, tooltip, (gpointer)callback, NULL, NULL, \
+    { GNOME_APP_UI_ITEM, label, tooltip, (gpointer) callback, NULL, NULL, \
         GNOME_APP_PIXMAP_FILENAME, filename, 0, (GdkModifierType) 0, NULL }
 
 
